using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace net1
{
    public partial class ListViewForm : Form, IDocumentView
    {
        private ListViewForm()
        {
            InitializeComponent();
        }

        public ListViewForm(Document doc, System.Windows.Forms.Form mdiParent) : this()
        {
            innerDoc = doc;
            MdiParent = mdiParent;
            doc.Register(this);

            foreach (Person person in doc.peopleList)
            {
                ListViewItem item = PersonToListViewItem(person);
                this.listView1.Items.Add(item);
            }

            this.Text = doc.docName;

            Show();
        }

        private ListViewItem PersonToListViewItem(Person person)
        {
            ListViewItem item = new ListViewItem(new string[] {
            person.personName,
            person.personHeight.ToString(),
            person.personWeigth.ToString(),
            person.personEyes.ToString() },
            0);
            item.Tag = person;
            return item;
        }

        Document innerDoc;

        public Document document
        {
            get { return innerDoc; }
        }

        public bool AddElement(Person person) {
            ListViewItem item = PersonToListViewItem(person);
            this.listView1.Items.Add(item);
            return true;
        }

        public bool DeleteElement(Person person) {
            foreach (ListViewItem item in this.listView1.Items)
            {
                if (item.Tag == person)
                {
                    this.listView1.Items.Remove(item);
                    return true;
                }
            }
            return false;
        }

        public bool ModifyElement(Person person)
        {
            foreach (ListViewItem item in this.listView1.Items)
            {
                if (item.Tag == person)
                {
                    item.Text = person.personName;
                    item.SubItems[1].Text = person.personHeight.ToString();
                    item.SubItems[2].Text = person.personWeigth.ToString();
                    item.SubItems[3].Text = person.personEyes.ToString();
                    return true;
                }
            }
            return false;
        }

        public bool UpdateTitle()
        {
            this.Text = document.docName;
            return true;
        }

        private void ListViewForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (e.CloseReason != CloseReason.MdiFormClosing && document.viewCount <= 1)
                e.Cancel = true;
        }

        private void dodajToolStripMenuItem_Click(object sender, EventArgs e)
        {
            document.AddElement();
        }

        private void usuToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.listView1.SelectedItems.Count > 0) document.DeleteElement((Person)this.listView1.SelectedItems[0].Tag);
        }

        private void modyfikujToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.listView1.SelectedItems.Count > 0) document.ModifyElement((Person)this.listView1.SelectedItems[0].Tag);
        }

        private void zachowajToolStripMenuItem_Click(object sender, EventArgs e)
        {
            document.SaveToFile();
        }

    }
}